Original Creator & Maintainer
===================
- DiepDT (@vituocgia)
--------------------------------------------

A sincere thanks to everyone who has helped make izi the great Python3 project it is today!

~DiepDT
